@@ -54,7 +54,7 @@ typedef enum {
  * @PANGO_ELLIPSIZE_START: Omit characters at the start of the text
  * @PANGO_ELLIPSIZE_MIDDLE: Omit characters in the middle of the text
  * @PANGO_ELLIPSIZE_END: Omit characters at the end of the text
- * 
+ *
  * The #PangoEllipsizeMode type describes what sort of (if any)
  * ellipsization should be applied to a line of text. In
  * the ellipsization process characters are removed from the
@@ -74,7 +74,7 @@ struct _PangoLayoutLine
   gint         start_index;     /* start of line as byte index into layout->text */
   gint         length;		/* length of line in bytes */
   GSList      *runs;
-  guint        is_paragraph_start : 1;  /* TRUE if this is the first line of the paragraph */ 
+  guint        is_paragraph_start : 1;  /* TRUE if this is the first line of the paragraph */
   guint        resolved_dir : 3;  /* Resolved PangoDirection of line */
 };
 
@@ -105,14 +105,14 @@ void           pango_layout_set_text       (PangoLayout    *layout,
 const char    *pango_layout_get_text       (PangoLayout    *layout);
 
 void           pango_layout_set_markup     (PangoLayout    *layout,
-                                            const char     *markup,
-                                            int             length);
+					    const char     *markup,
+					    int             length);
 
 void           pango_layout_set_markup_with_accel (PangoLayout    *layout,
-                                                   const char     *markup,
-                                                   int             length,
-                                                   gunichar        accel_marker,
-                                                   gunichar       *accel_char);
+						   const char     *markup,
+						   int             length,
+						   gunichar        accel_marker,
+						   gunichar       *accel_char);
 
 void           pango_layout_set_font_description (PangoLayout                *layout,
 						  const PangoFontDescription *desc);
@@ -123,8 +123,9 @@ void           pango_layout_set_width            (PangoLayout                *la
 						  int                         width);
 int            pango_layout_get_width            (PangoLayout                *layout);
 void           pango_layout_set_wrap             (PangoLayout                *layout,
-                                                  PangoWrapMode               wrap);
+						  PangoWrapMode               wrap);
 PangoWrapMode  pango_layout_get_wrap             (PangoLayout                *layout);
+gboolean       pango_layout_is_wrapped           (PangoLayout                *layout);
 void           pango_layout_set_indent           (PangoLayout                *layout,
 						  int                         indent);
 int            pango_layout_get_indent           (PangoLayout                *layout);
@@ -134,27 +135,30 @@ int            pango_layout_get_spacing          (PangoLayout                *la
 void           pango_layout_set_justify          (PangoLayout                *layout,
 						  gboolean                    justify);
 gboolean       pango_layout_get_justify          (PangoLayout                *layout);
-void           pango_layout_set_auto_dir          (PangoLayout                *layout,
+void           pango_layout_set_auto_dir         (PangoLayout                *layout,
 						  gboolean                    auto_dir);
-gboolean       pango_layout_get_auto_dir          (PangoLayout                *layout);
+gboolean       pango_layout_get_auto_dir         (PangoLayout                *layout);
 void           pango_layout_set_alignment        (PangoLayout                *layout,
 						  PangoAlignment              alignment);
 PangoAlignment pango_layout_get_alignment        (PangoLayout                *layout);
 
 void           pango_layout_set_tabs             (PangoLayout                *layout,
-                                                  PangoTabArray              *tabs);
+						  PangoTabArray              *tabs);
 
 PangoTabArray* pango_layout_get_tabs             (PangoLayout                *layout);
 
 void           pango_layout_set_single_paragraph_mode (PangoLayout                *layout,
-                                                       gboolean                    setting);
+						       gboolean                    setting);
 gboolean       pango_layout_get_single_paragraph_mode (PangoLayout                *layout);
 
 void               pango_layout_set_ellipsize (PangoLayout        *layout,
 					       PangoEllipsizeMode  ellipsize);
 PangoEllipsizeMode pango_layout_get_ellipsize (PangoLayout        *layout);
+gboolean           pango_layout_is_ellipsized (PangoLayout        *layout);
 
-void           pango_layout_context_changed (PangoLayout    *layout);
+int      pango_layout_get_unknown_glyphs_count (PangoLayout    *layout);
+
+void     pango_layout_context_changed (PangoLayout    *layout);
 
 void     pango_layout_get_log_attrs (PangoLayout    *layout,
 				     PangoLogAttr  **attrs,
@@ -164,10 +168,10 @@ void     pango_layout_index_to_pos         (PangoLayout    *layout,
 					    int             index_,
 					    PangoRectangle *pos);
 void     pango_layout_index_to_line_x      (PangoLayout    *layout,
-			                    int             index_,
-			                    gboolean        trailing,
-			                    int            *line,
-			                    int            *x_pos);
+					    int             index_,
+					    gboolean        trailing,
+					    int            *line,
+					    int            *x_pos);
 void     pango_layout_get_cursor_pos       (PangoLayout    *layout,
 					    int             index_,
 					    PangoRectangle *strong_pos,
@@ -205,6 +209,7 @@ PangoLayoutLine *pango_layout_get_line_readonly    (PangoLayout    *layout,
 GSList *         pango_layout_get_lines            (PangoLayout    *layout);
 GSList *         pango_layout_get_lines_readonly   (PangoLayout    *layout);
 
+
 #define PANGO_TYPE_LAYOUT_LINE (pango_layout_line_get_type ())
 
 GType    pango_layout_line_get_type     (void) G_GNUC_CONST;
@@ -254,25 +259,25 @@ gboolean pango_layout_iter_next_run     (PangoLayoutIter *iter);
 gboolean pango_layout_iter_next_line    (PangoLayoutIter *iter);
 
 void pango_layout_iter_get_char_extents    (PangoLayoutIter *iter,
-                                            PangoRectangle  *logical_rect);
+					    PangoRectangle  *logical_rect);
 void pango_layout_iter_get_cluster_extents (PangoLayoutIter *iter,
-                                            PangoRectangle  *ink_rect,
-                                            PangoRectangle  *logical_rect);
+					    PangoRectangle  *ink_rect,
+					    PangoRectangle  *logical_rect);
 void pango_layout_iter_get_run_extents     (PangoLayoutIter *iter,
-                                            PangoRectangle  *ink_rect,
-                                            PangoRectangle  *logical_rect);
+					    PangoRectangle  *ink_rect,
+					    PangoRectangle  *logical_rect);
 void pango_layout_iter_get_line_extents    (PangoLayoutIter *iter,
-                                            PangoRectangle  *ink_rect,
-                                            PangoRectangle  *logical_rect);
+					    PangoRectangle  *ink_rect,
+					    PangoRectangle  *logical_rect);
 /* All the yranges meet, unlike the logical_rect's (i.e. the yranges
  * assign between-line spacing to the nearest line)
  */
 void pango_layout_iter_get_line_yrange     (PangoLayoutIter *iter,
-                                            int             *y0_,
-                                            int             *y1_);
+					    int             *y0_,
+					    int             *y1_);
 void pango_layout_iter_get_layout_extents  (PangoLayoutIter *iter,
-                                            PangoRectangle  *ink_rect,
-                                            PangoRectangle  *logical_rect);
+					    PangoRectangle  *ink_rect,
+					    PangoRectangle  *logical_rect);
 int  pango_layout_iter_get_baseline        (PangoLayoutIter *iter);
 
 G_END_DECLS
