@@ -27,6 +27,14 @@
 
 G_BEGIN_DECLS
 
+typedef struct _PangoFcMetricsInfo  PangoFcMetricsInfo;
+
+struct _PangoFcMetricsInfo
+{
+  const char       *sample_str;
+  PangoFontMetrics *metrics;
+};
+
 #define PANGO_SCALE_26_6 (PANGO_SCALE / (1<<6))
 #define PANGO_PIXELS_26_6(d)				\
   (((d) >= 0) ?						\
@@ -34,6 +42,8 @@ G_BEGIN_DECLS
    ((d) - PANGO_SCALE_26_6 / 2) / PANGO_SCALE_26_6)
 #define PANGO_UNITS_26_6(d) (PANGO_SCALE_26_6 * (d))
 
+#define PANGO_FC_GRAVITY "pangogravity"
+
 void _pango_fc_font_shutdown (PangoFcFont *fcfont);
 
 void           _pango_fc_font_map_remove          (PangoFcFontMap *fcfontmap,
@@ -46,12 +56,19 @@ PangoFcDecoder *_pango_fc_font_get_decoder       (PangoFcFont    *font);
 void            _pango_fc_font_set_decoder       (PangoFcFont    *font,
 						  PangoFcDecoder *decoder);
 
+gpointer        _pango_fc_font_get_context_key   (PangoFcFont    *font);
+void            _pango_fc_font_set_context_key   (PangoFcFont    *font,
+						  gpointer        context_key);
+
 void            pango_fc_font_get_raw_extents    (PangoFcFont    *font,
 						  FT_Int32        load_flags,
 						  PangoGlyph      glyph,
 						  PangoRectangle *ink_rect,
 						  PangoRectangle *logical_rect);
 
+PangoFontMetrics *pango_fc_font_create_metrics_for_context (PangoFcFont   *font,
+							    PangoContext  *context);
+
 G_END_DECLS
 
 #endif /* __PANGOFC_PRIVATE_H__ */
